@@ -1,4 +1,4 @@
- emma.eigen.L.w.Z <- function (Z, K, complete = TRUE, ngpu=0)
+emma.eigen.L.w.Z <- function (Z, K, complete = TRUE )
 {
     if (complete == FALSE) {
         vids <- colSums(Z) > 0
@@ -12,4 +12,3 @@
         eig$vectors), complete = TRUE)))
 }
 
-
